@@ -22,7 +22,7 @@ use Travel::Status::DE::HAFAS::Product;
 use Travel::Status::DE::HAFAS::Services;
 use Travel::Status::DE::HAFAS::StopFinder;
 
-our $VERSION = '6.08';
+our $VERSION = '6.09';
 
 # {{{ Endpoint Definition
 
@@ -885,7 +885,7 @@ monitors
 
 =head1 VERSION
 
-version 6.08
+version 6.09
 
 =head1 DESCRIPTION
 
@@ -1124,18 +1124,29 @@ nothing otherwise. The hashref contains the following keys.
 
 =over
 
-=item B<name> => I<string>
+=item B<coverage> => I<hashref>
 
-service name, e.g. Bay Area Rapid Transit or Deutsche Bahn.
+Area in which the service provides near-optimal coverage. Typically, this means
+a (nearly) complete list of departures and real-time data. The hashref contains
+two optional keys: B<area> (GeoJSON) and B<regions> (list of strings, e.g. "DE"
+or "CH-BE").
 
-=item B<mgate> => I<string>
+=item B<homepage> => I<string>
 
-HAFAS backend URL
+Homepage URL of the service provider.
 
 =item B<languages> => I<arrayref>
 
 Languages supported by the backend; see the constructor's B<language> argument.
 
+=item B<name> => I<string>
+
+Service name, e.g. Bay Area Rapid Transit or Deutsche Bahn.
+
+=item B<mgate> => I<string>
+
+HAFAS backend URL
+
 =item B<productbits> => I<arrayref>
 
 MOT bits supported by the backend. I<arrayref> contains either strings
